/**
 * SEO component that queries for data with
 *  Gatsby's useStaticQuery React hook
 *
 * See: https://www.gatsbyjs.org/docs/use-static-query/
 */

import React from 'react';
import PropTypes from 'prop-types';
import Helmet from 'react-helmet';
//  import { usePageContext } from 'pieces/utils/context';
import { useLocation } from '@gatsbyjs/reach-router';
import // revertPathToDefaultLocale
// localizePath,
'../utils/functions';
import { useSiteMetadata } from '../utils/hooks';

export function SEO({
  description,
  meta,
  title,
  shortTitle,
  shortDescription,
  url,
  link
}) {
  const location = useLocation();
  //  TODO:  const { locale } = usePageContext();

  const siteMetadata = useSiteMetadata();

  // console.log(`location.pathname`, location.pathname);

  // const cleanedPathname = revertPathToDefaultLocale(
  //   location.pathname,
  //   siteMetadata.locales?.translations || [],
  //   siteMetadata.translatedPaths || []
  // );

  console.log('siteMetadata.locales?.default', siteMetadata.locales?.default);

  // If locale not specified in siteMetadata, use "en"
  const pageLang = siteMetadata.locales?.default || 'en';
  const metaDescription = description || siteMetadata.description;
  // eslint-disable-next-line operator-linebreak
  const metaShortDescription =
    shortDescription || siteMetadata.shortDescription;
  const metaTitle = title || siteMetadata.title;
  const metaShortTitle = shortTitle || siteMetadata.shortTitle;
  const metaUrl = url || siteMetadata.url;

  return (
    <Helmet
      htmlAttributes={{
        lang: pageLang
      }}
      link={[
        // default lang
        {
          rel: 'alternate',
          hreflang: pageLang,
          href: siteMetadata.url + location.pathname
        },
        // {
        //   rel: 'alternate',
        //   hreflang: 'de',
        //   href: siteMetadata.url + localizePath(cleanedPathname, 'deDE'),
        // },
        {
          rel: 'alternate',
          hreflang: 'x-default',
          href: siteMetadata.url + location.pathname
        },
        {
          rel: 'image_src',
          type: 'image/png',
          href: siteMetadata.thumbnail.images.fallback.src
        },
        {
          rel: 'icon',
          type: 'image/png',
          sizes: '32x32',
          href: siteMetadata.favicon32.src
        },
        {
          rel: 'icon',
          type: 'image/png',
          sizes: '16x16',
          href: siteMetadata.favicon16.src
        },
        {
          rel: 'shortcut icon',
          type: 'image/png',
          href: siteMetadata.favicon64.src
        }
      ].concat(link)}
      meta={[
        {
          name: 'description',
          content: metaDescription
        },
        {
          property: 'og:title',
          content: metaShortTitle
        },
        {
          property: 'og:description',
          content: metaShortDescription
        },
        {
          property: 'og:url',
          content: metaUrl
        },
        {
          property: 'og:image',
          content: siteMetadata.thumbnail
        },
        {
          name: 'twitter:card',
          content: 'summary'
        },
        {
          name: 'twitter:creator',
          content: siteMetadata.author
        },
        {
          name: 'twitter:title',
          content: title
        },
        {
          name: 'twitter:description',
          content: metaDescription
        }
      ].concat(meta)}
      title={metaTitle}
      titleTemplate={`%s | ${siteMetadata.title}`}
    />
  );
}

SEO.defaultProps = {
  meta: [],
  description: '',
  shortTitle: null,
  shortDescription: null,
  url: null,
  link: []
};

SEO.propTypes = {
  description: PropTypes.string,
  link: PropTypes.arrayOf(PropTypes.object),
  meta: PropTypes.arrayOf(PropTypes.object),
  shortTitle: PropTypes.string,
  shortDescription: PropTypes.string,
  title: PropTypes.string.isRequired,
  url: PropTypes.string
};
